==> neurodebian_0.38.3.tar.xz: neurodebian-0.38.3/README.md <==
                                  ==  ===============   === =
                           =  ================================
                      = ======= =        =  ==      ==============
                    ======                             = ============ = =
                ====== =                                  = ============ =
            = =======                                        = ============
          ===========                                             ==========
          ===== =                                                 = ==========
       ===== =                                                        ========
      ======                                                            ======
     =====                                           =                  =======
     ====                                            =                    ======
     ====                        ==   ==  =  == = ==                      ======
    =====                  = ======== =  ==   =                            ======
    ====              =  =====  ==                                         ======
    ===               ===== =                                               ======
    ===               ===                                                 =======
      =            = ==                                                 = ========
      =  =        =====                                             =============
                 =  ==                                        ==  =============
                 == ===                                 =   ================ =
                   =====                          == ================== ==
                  ==  ==== =                 =  ============ = ===  =
                       = ===== ===   ==  =============   == = =
                          = ====================   ==

[NeuroDebian](http://neuro.debian.net) is a popular turnkey platform for
Neuroscience, where software is integrated, tested, and delivered
conviniently and reliably so you could concentrate on your research and
not on "system maintenance".  It provides a large collection of popular
neuroscience research software for the Debian operating system as well
as Ubuntu and other derivatives.  Please visit our
[main website](http://neuro.debian.net) to discover more.

[![Travis tests status](https://secure.travis-ci.org/neurodebian/neurodebian.png?branch=master)](https://travis-ci.org/datalad/datalad)
[![Docker](http://dockeri.co/image/_/neurodebian)](https://hub.docker.com/_/neurodebian/)
[![https://www.singularity-hub.org/static/img/hosted-singularity--hub-%23e32929.svg](https://www.singularity-hub.org/static/img/hosted-singularity--hub-%23e32929.svg)](https://singularity-hub.org/collections/209)

# Related projects from the NeuroDebian authors

- [Open Brain Constent](http://open-brain-consent.readthedocs.io) - samples
  and an ultimate wording for experiment participant consent forms to make
  open data sharing possible
- [DataLad](http://datalad.org) - a data distribution and management
  platform, which addresses shortcomings of solutions of software/code-oriented
  solutions (such as NeuroDebian and pure git), when applied to data
- [ReproIn](http://reproin.repronim.org) - a turnkey solution for collecting
  MRI data directly as [BIDS](http://bids.neuroimaging.io) DataLad datasets
- [DueCredit](duecredit.org) - Automated collection and reporting of
  citations for used software/methods/datasets
- [Study Forrest](http://studyforrest.org) -  a diverse and
  ever-expanding collection of data and studies on our favorite shrimping,
  cross-country running, international ping-pong champion: *Forrest Gump*
- [PyMVPA](http://pymvpa.org) - a machine learning framework for the analysis
  of (not only) neuroimaging data
- Discover more about these and other projects from
  [Center for Open Neuroscience](http://centerforopenneuroscience.org) and
  [Psychoinformatics](http://psychoinformatics.de).

==> neurodebian_0.40.1.tar.xz: neurodebian-0.40.1/README.md <==
                                  ==  ===============   === =
                           =  ================================
                      = ======= =        =  ==      ==============
                    ======                             = ============ = =
                ====== =                                  = ============ =
            = =======                                        = ============
          ===========                                             ==========
          ===== =                                                 = ==========
       ===== =                                                        ========
      ======                                                            ======
     =====                                           =                  =======
     ====                                            =                    ======
     ====                        ==   ==  =  == = ==                      ======
    =====                  = ======== =  ==   =                            ======
    ====              =  =====  ==                                         ======
    ===               ===== =                                               ======
    ===               ===                                                 =======
      =            = ==                                                 = ========
      =  =        =====                                             =============
                 =  ==                                        ==  =============
                 == ===                                 =   ================ =
                   =====                          == ================== ==
                  ==  ==== =                 =  ============ = ===  =
                       = ===== ===   ==  =============   == = =
                          = ====================   ==

[NeuroDebian](http://neuro.debian.net) is a popular turnkey platform for
Neuroscience, where software is integrated, tested, and delivered
conveniently and reliably so you could concentrate on your research and
not on "system maintenance".  It provides a large collection of popular
neuroscience research software for the Debian operating system as well
as Ubuntu and other derivatives.  Please visit our
[main website](http://neuro.debian.net) to discover more.

[![Travis tests status](https://secure.travis-ci.org/neurodebian/neurodebian.png?branch=master)](https://travis-ci.org/neurodebian/neurodebian)
[![Docker](http://dockeri.co/image/_/neurodebian)](https://hub.docker.com/_/neurodebian/)
[![https://www.singularity-hub.org/static/img/hosted-singularity--hub-%23e32929.svg](https://www.singularity-hub.org/static/img/hosted-singularity--hub-%23e32929.svg)](https://singularity-hub.org/collections/209)

# Related projects from the NeuroDebian authors

- [Open Brain Constent](http://open-brain-consent.readthedocs.io) - samples
  and an ultimate wording for experiment participant consent forms to make
  open data sharing possible
- [DataLad](http://datalad.org) - a data distribution and management
  platform, which addresses shortcomings of solutions of software/code-oriented
  solutions (such as NeuroDebian and pure git), when applied to data
- [ReproIn](http://reproin.repronim.org) - a turnkey solution for collecting
  MRI data directly as [BIDS](http://bids.neuroimaging.io) DataLad datasets
- [DueCredit](duecredit.org) - Automated collection and reporting of
  citations for used software/methods/datasets
- [Study Forrest](http://studyforrest.org) -  a diverse and
  ever-expanding collection of data and studies on our favorite shrimping,
  cross-country running, international ping-pong champion: *Forrest Gump*
- [PyMVPA](http://pymvpa.org) - a machine learning framework for the analysis
  of (not only) neuroimaging data
- Discover more about these and other projects from
  [Center for Open Neuroscience](http://centerforopenneuroscience.org) and
  [Psychoinformatics](http://psychoinformatics.de).
